<template>
  <div class="app-container">
    <div style="margin-bottom: 10px">
      <el-form style="display: flex;flex-wrap: wrap;">
        <el-form-item>
          <el-button
              type="primary"
              plain
              icon="Plus"
              @click="openDialog('add',{})"
          >新增</el-button>
        </el-form-item>
        <el-form-item label="企业名称:" v-if="data.isAdmin" style="margin-left: 20px">
          <el-select v-model="data.queryParams.companyId" filterable placeholder="请选择" clearable>
            <el-option
                v-for="item in data.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item v-if="data.isAdmin">
          <el-button type="primary" style="margin-left: 30px" @click="searchClick">查询</el-button>
          <el-button plain @click="reset">重置</el-button>
        </el-form-item>
        <el-form-item style="margin-left: 15px">
          <vue3-json-excel
              :json-data="dataList"
              :fields="data.isAdmin ? fieldsAdmin : fields"
              name="培训计划表.xlsx"
          >
            <el-button type="primary">导出</el-button>
          </vue3-json-excel>
<!--          <el-button-->
<!--              type="primary"-->
<!--              @click="exportData"-->
<!--          >导出</el-button>-->
        </el-form-item>

      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true"  @selection-change="handleSelectionChange">
      <el-table-column type="index" label="序号" width="80" align="center"></el-table-column>
      <el-table-column label="企业名称" v-if="data.isAdmin" prop="companyName" align="center" />
      <el-table-column label="时间" prop="trainTime" align="center" />
      <el-table-column label="课程名称" prop="trainName" align="center" />
      <el-table-column label="组织部门" prop="deptName" align="center" />
      <el-table-column label="参训对象" prop="trainObject" align="center" />
      <el-table-column label="人数" prop="num" align="center" />
      <el-table-column label="课时" prop="hour" align="center" />
      <el-table-column label="费用预算(元)" prop="money" align="center" />
      <el-table-column label="培训形式" prop="modality" align="center" />
      <el-table-column label="是否已完成" prop="status" align="center">
        <template #default="scope">
          <span>{{scope.row.status == 0 ? '是' :scope.row.status == 1 ?'否': ''}}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
        <template #default="scope">
          <el-button link type="primary"  @click="openDialog('edit',scope.row)" >编辑</el-button>
          <el-button link type="danger"  @click="handleDelete(scope.row)" >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <div class="pag-container">
      <el-pagination
          v-model:current-page="data.queryParams.pageNum"
          v-model:page-size="data.queryParams.pageSize"
          :page-sizes="[10,15,20,25]"
          layout="total, sizes, prev, pager, next, jumper"
          :total="total"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
      />
    </div>
    <trainDialog ref="noticeRef" @getList = "getList"></trainDialog>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, reactive, ref, toRefs} from "vue";
import trainDialog from "./components/trainDialog.vue"
import {ElMessage, ElMessageBox} from "element-plus";
import {getCompany} from "@/api/onlineEducation/company";
import Cookies from "js-cookie";
import {generateWordDocument} from "@/utils/exportWord";
import {delBasic, getBasic} from "@/api/companyInfo/basicInfo";
import {delScenario, getScenarioPage} from "@/api/selfProblems/scenario";
import {delTrainPlan, getTrainPlanPage} from "@/api/onlineEducation/trainPlan";

const { proxy } = getCurrentInstance();
const loading = ref(false);
const noticeRef = ref();
const loadingCompany = ref(false)
const choosedData = ref([])
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    companyId: null,
  },
  companyList: [],
  isAdmin: false,
  expertData: []
});
const dataList = ref([]);
const total = ref(0);

const { queryParams } = toRefs(data);
const fieldsAdmin = ref({
  '企业名称': 'companyName',
  '时间':'trainTime',
  '课程名称':'trainName',
  '组织部门':'deptName',
  '参训对象':'trainObject',
  '人数':'num',
  '课时':'hour',
  '费用预算(元)':'money',
  '培训形式':'modality',
  '是否已完成':'statusName',
});
const fields = ref({
  '时间':'trainTime',
  '课程名称':'trainName',
  '组织部门':'deptName',
  '参训对象':'trainObject',
  '人数':'num',
  '课时':'hour',
  '费用预算(元)':'money',
  '培训形式':'modality',
  '是否已完成':'statusName',
});
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  data.isAdmin = userInfo.userType === 0;
  if(data.isAdmin){
    data.queryParams.companyId = null
    getCompanyList()
  }else {
    data.queryParams.companyId = userInfo.companyId
  }
  getList();
});
const getList = async () => {
  loading.value = true;
  const res = await getTrainPlanPage(data.queryParams);
  if(res.code === 200){
    dataList.value = res.data.list.map(item => {
      return {
        ...item,
        trainTime: item.trainTime.substring(0,10),
        statusName: item.status == 0 ? '是' : item.status == 1 ? '否' : ''
      }
    })
    total.value = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false;

}

const searchClick = () => {
  getList();
}
const openDialog = (type, value) => {
  noticeRef.value.openDialog(type, value,data.companyList);
}

const getCompanyList = async ()=>{
  const queryParams = {
    pageNum: 1,
    pageSize: 999
  }
  const res = await getCompany(queryParams)
  if (res.code == 200) {
    data.companyList = res.data.list?res.data.list:[]
  } else {
    ElMessage.warning(res.message)
  }
}

const handleSizeChange = (val) => {
  data.queryParams.pageSize = val
  getList()
}
const handleCurrentChange = (val) => {
  data.queryParams.pageNum = val
  getList()
}

/** 重置新增的表单以及其他数据  */
function reset() {
  data.queryParams = {
    companyId: '',
    pageNum: 1,
    pageSize: 10,
  }
  choosedData.value = []
  data.companyList = [];
  getList();
  getCompanyList()
}
const exportData = () => {
  if(choosedData.value && choosedData.value.length === 0){
    ElMessage.warning('请选择需要导出的数据')
  }else {
    startGeneration()
  }
}
const templatePath = '/scenarioExample.docx'
const startGeneration = async () => {
  choosedData.value.forEach(item => {
    try {
      item.title = item.year+'年度内部审核策划方案'
      generateWordDocument(templatePath, item, item.companyName+ '_' + item.title +'.docx');
    } catch (error){
      ElMessage({
        type: 'warning',
        message: '导出失败'
      });
    }
  })
}

const handleSelectionChange = (val) => {
  choosedData.value = val
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delTrainPlan(val.id);
        if(res.code === 200){
          ElMessage({
            type: 'success',
            message: '删除成功'
          });
          getList();
        }else{
          ElMessage.warning(res.message)
        }
      })
}

</script>
<style lang="scss">
.pag-container{
  float: right;
  margin-top: 10px;
}
</style>
